@@ -1,4 +1,3 @@
-from types import SimpleNamespace
 from typing import Dict, List
 
 from .base import BaseService
@@ -25,33 +24,33 @@ class QueriesService(
         self.__base = base
         self.endpoint = "/api/queries"
 
-    def refresh(self, query_id: int) -> SimpleNamespace:
+    def refresh(self, query_id: int) -> Dict:
         """Refresh a query"""
         return self.__base.post(f"{self.endpoint}/{query_id}/results", dict(max_age=0))
 
-    def fork(self, query_id: int) -> SimpleNamespace:
+    def fork(self, query_id: int) -> Dict:
         """Fork a query"""
         return self.__base.post(f"{self.endpoint}/{query_id}/fork", {"id": query_id})
 
     def duplicate_query_table(
         self,
         *,
-        query: SimpleNamespace,
+        query: Dict,
         table_map: Dict[str, str],
         tags: List[str],
         publish: bool = True,
-    ) -> SimpleNamespace:
+    ) -> Dict:
         """
         Duplicate query with source tables replaced according to table_map.
 
         Args:
-            query(SimpleNamespace): query data object
+            query(Dict): query data object
             table_map(Dict): mapping of old to new tables
             tags(List): tags to add to new query
             publish(bool): whether to publish the new query
 
         Returns:
-            SimpleNamespace: new query data object
+            Dict: new query data object
 
         Example:
             >>> query = queries.get(query_id)
@@ -65,19 +64,19 @@ class QueriesService(
             >>> )
         """
 
-        new_id = self.fork(query.id).id
+        new_id = self.fork(query.get("id")).get("id")
 
         # update query
         new_query = self.get(new_id)
-        new_query.name = query.name
-        new_query.tags = tags
+        new_query["name"] = query.get("name")
+        new_query["tags"] = tags
 
         for old, new in list(table_map.items()):
-            new_query.query = new_query.query.replace(old, new)
+            new_query["query"] = new_query.get("query").replace(old, new)
         self.update(new_id, new_query)
 
         # run updated query to update results
-        self.refresh(new_query.id)
+        self.refresh(new_query.get("id"))
 
         # finally publish the new query
         if publish:
